==> ad_suyi_flutter_sdk-1.0.7.tar.gz: example/lib/splashLoadShowSeparate.dart <==
import 'package:ad_suyi_flutter_sdk/ad_suyi_ad.dart';
import 'package:ad_suyi_flutter_sdk/ad_suyi_base.dart';
import 'package:flutter/material.dart';
import 'package:flutter/material.dart';

import 'main.dart';
import 'key.dart';

class SplashLoadShowSeparatePage extends StatefulWidget {
  @override
  State<StatefulWidget> createState() => _SplashLoadShowSeparateState();
}

class _SplashLoadShowSeparateState extends State<SplashLoadShowSeparatePage> {
  ADSuyiSplashAdLoadShowSeparate? _adSuyiFlutterSplashAd;
  bool _hasInitBanner = false;

  @override
  Widget build(BuildContext context) {
    if (_adSuyiFlutterSplashAd == null && _hasInitBanner == false) {
      MediaQueryData queryData = MediaQuery.of(context);
      _hasInitBanner = true;
      var width = queryData.size.width;
      var height = queryData.size.height;
      _adSuyiFlutterSplashAd = ADSuyiSplashAdLoadShowSeparate(
          posId: KeyManager.splashPosid(), width: width, height: height);
      _adSuyiFlutterSplashAd!.load();
      _adSuyiFlutterSplashAd!.onSucced = () {
        print("开屏广告加载成功");
        _adSuyiFlutterSplashAd!.show();
      };
      _adSuyiFlutterSplashAd!.onFailed = () {
        releaseSplashAd();
        print("开屏广告加载失败");
        toHome();
      };
      _adSuyiFlutterSplashAd!.onClicked = () {
        print("开屏广告点击");
      };
      _adSuyiFlutterSplashAd!.onExposed = () {
        print("开屏广告渲染成功");
      };
      _adSuyiFlutterSplashAd!.onClosed = () {
        releaseSplashAd();
        print("开屏广告关闭成功");
        toHome();
      };
    }

    return Scaffold(
        body: Center(
            child: (_adSuyiFlutterSplashAd == null
                ? Text("开屏广告已关闭")
                : ADSuyiWidget(adView: _adSuyiFlutterSplashAd!))));
  }

  void toHome() {
    Navigator.pushAndRemoveUntil(
      context,
      new MaterialPageRoute(builder: (context) => new MyApp()),
          (route) => route == null,
    );
  }

  void removeSplashAd() {
    setState(() {
      releaseSplashAd();
    });
  }

  void releaseSplashAd() {
    _adSuyiFlutterSplashAd?.release();
    _adSuyiFlutterSplashAd = null;
  }

  @override
  void dispose() {
    releaseSplashAd();
    super.dispose();
  }
}

==> ad_suyi_flutter_sdk-1.0.9.tar.gz: example/lib/splashLoadShowSeparate.dart <==
import 'package:ad_suyi_flutter_sdk/ad_suyi_ad.dart';
import 'package:ad_suyi_flutter_sdk/ad_suyi_base.dart';
import 'package:flutter/material.dart';
import 'package:flutter/material.dart';

import 'main.dart';
import 'key.dart';

class SplashLoadShowSeparatePage extends StatefulWidget {
  @override
  State<StatefulWidget> createState() => _SplashLoadShowSeparateState();
}

class _SplashLoadShowSeparateState extends State<SplashLoadShowSeparatePage> {
  ADSuyiSplashAdLoadShowSeparate? _adSuyiFlutterSplashAd;
  bool _hasInitBanner = false;

  @override
  Widget build(BuildContext context) {
    if (_adSuyiFlutterSplashAd == null && _hasInitBanner == false) {
      MediaQueryData queryData = MediaQuery.of(context);
      _hasInitBanner = true;
      var width = queryData.size.width;
      var height = queryData.size.height;
      _adSuyiFlutterSplashAd = ADSuyiSplashAdLoadShowSeparate(
          posId: KeyManager.splashPosid(),
          width: width,
          height: height,
          imgName: "splash_placeholder",
          imgLogoName: "splash_logo",
      );
      // imgName、imgLogoName iOS 使用
      _adSuyiFlutterSplashAd!.load();
      _adSuyiFlutterSplashAd!.onSucced = () {
        print("开屏广告加载成功");
        _adSuyiFlutterSplashAd!.show();
      };
      _adSuyiFlutterSplashAd!.onFailed = () {
        releaseSplashAd();
        print("开屏广告加载失败");
        toHome();
      };
      _adSuyiFlutterSplashAd!.onClicked = () {
        print("开屏广告点击");
      };
      _adSuyiFlutterSplashAd!.onExposed = () {
        print("开屏广告渲染成功");
      };
      _adSuyiFlutterSplashAd!.onClosed = () {
        releaseSplashAd();
        print("开屏广告关闭成功");
        toHome();
      };
    }

    return Scaffold(
        body: Center(
            child: (_adSuyiFlutterSplashAd == null
                ? Text("开屏广告已关闭")
                : ADSuyiWidget(adView: _adSuyiFlutterSplashAd!))));
  }

  void toHome() {
    Navigator.pushAndRemoveUntil(
      context,
      new MaterialPageRoute(builder: (context) => new MyApp()),
          (route) => route == null,
    );
  }

  void removeSplashAd() {
    setState(() {
      releaseSplashAd();
    });
  }

  void releaseSplashAd() {
    _adSuyiFlutterSplashAd?.release();
    _adSuyiFlutterSplashAd = null;
  }

  @override
  void dispose() {
    releaseSplashAd();
    super.dispose();
  }
}
